Module device

Module device 

Hardware devices interfaces

Structs

AsyncDevice
An asynchronous version of Device.
AsyncDevicePoller
Capabilities
A bitflag struct for values of the CEC_CAP_* constants
Device
An object for interacting with system CEC devices.
DevicePoller
An object used for polling the status of the event and message queues in the kernel without borrowing the Device, created by Device::get_poller.
Envelope
A representation of a received Message and its associated metadata.
PinEvent
An event representing a logic level change of a physical pin.
PollTimeout
PollTimeout argument for polling.

Enums

ConnectorInfo
Information about how the CEC device is connected to the system.
MessageData
An enum containing the message data, either successfully parsed or invalid.
Pin
A physical pin that can be monitored via PinEvents.
PinState
The logic level of a physical pin as reported in a PinEvent.
PollResult
A return result of Device::handle_status, containing about a single message or event was returned from the kernel.
PollStatus
Information from a DevicePoller about which information is available from the kernel, to be passed to Device::handle_status.