#[non_exhaustive]pub enum PollResult {
Message(Envelope),
PinEvent(PinEvent),
LostMessages(u32),
StateChange,
}Expand description
A return result of Device::handle_status, containing
about a single message or event was returned from the kernel.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Message(Envelope)
The device received a Message.
PinEvent(PinEvent)
A monitored pin changed state.
LostMessages(u32)
The message queue was full and a number of messages were received and lost. To avoid this, make sure to poll as frequently as possible.
StateChange
The device state changed. Usually this means the device was configured, unconfigured, or the physical address changed. If the caller has cached any properties like logical address or physical address, these values should be refreshed.