PollStatus

Enum PollStatus 

#[non_exhaustive]
pub enum PollStatus { Nothing, Destroyed, GotEvent, GotMessage, GotAll, }
Information from a DevicePoller about which information is available from the kernel, to be passed to Device::handle_status.

As this is a representation of what data is available and not used for requesting data manually, it should not be constructed directly.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Nothing



Destroyed



GotEvent



GotMessage



GotAll

Implementations

Source

impl PollStatus

pub fn got_message(&self) -> bool

pub fn got_event(&self) -> bool