AsyncDevice

Struct AsyncDevice 

pub struct AsyncDevice { /* private fields */ }
An asynchronous version of Device.

As this is simply an asynchronous interface for the standard Device struct, refer to the documentation there for information about the individual methods.

Implementations

Source

impl AsyncDevice

pub async fn open(path: impl AsRef<Path>) -> Result<AsyncDevice>

pub async fn set_blocking(&self, blocking: bool) -> Result<()>

pub async fn get_poller(&self) -> Result<AsyncDevicePoller>

pub async fn poll(&self, timeout: PollTimeout) -> Result<Vec<PollResult>>

pub async fn get_initiator_mode(&self) -> Result<InitiatorMode>

pub async fn set_initiator_mode(&self, mode: InitiatorMode) -> Result<()>

pub async fn get_follower_mode(&self) -> Result<FollowerMode>

pub async fn set_follower_mode(&self, mode: FollowerMode) -> Result<()>

pub async fn get_capabilities(&self) -> Result<Capabilities>

pub async fn get_raw_capabilities(&self) -> Result<cec_caps>

pub async fn get_driver_name(&self) -> Result<OsString>

pub async fn get_adapter_name(&self) -> Result<OsString>

pub async fn get_physical_address(&self) -> Result<PhysicalAddress>

pub async fn set_physical_address( &self, phys_addr: PhysicalAddress, ) -> Result<()>

pub async fn get_logical_addresses(&self) -> Result<Vec<LogicalAddress>>

pub async fn set_logical_addresses( &self, log_addrs: &[LogicalAddressType], ) -> Result<()>

pub async fn set_logical_address( &self, log_addr: LogicalAddressType, ) -> Result<()>

pub async fn clear_logical_addresses(&self) -> Result<()>

pub async fn get_osd_name(&self) -> Result<OsString>

pub async fn set_osd_name(&self, name: &str) -> Result<()>

pub async fn get_vendor_id(&self) -> Result<Option<VendorId>>

pub async fn set_vendor_id(&self, vendor_id: Option<VendorId>) -> Result<()>

pub async fn tx_message( &self, message: &Message, destination: LogicalAddress, ) -> Result<u32>

pub async fn tx_raw_message(&self, message: &mut cec_msg) -> Result<()>

pub async fn tx_rx_message( &self, message: &Message, destination: LogicalAddress, opcode: Opcode, timeout: Timeout, ) -> Result<Envelope>

pub async fn rx_message(&self, timeout: Timeout) -> Result<Envelope>

pub async fn rx_raw_message(&self, timeout: u32) -> Result<cec_msg>

pub async fn poll_address(&self, destination: LogicalAddress) -> Result<()>

pub async fn handle_status(&self, status: PollStatus) -> Result<Vec<PollResult>>

pub async fn get_connector_info(&self) -> Result<ConnectorInfo>

pub async fn set_active_source( &self, address: Option<PhysicalAddress>, ) -> Result<()>

pub async fn wake(&self, set_active: bool, text_view: bool) -> Result<()>

pub async fn standby(&self, target: LogicalAddress) -> Result<()>

pub async fn press_user_control( &self, ui_command: UiCommand, target: LogicalAddress, ) -> Result<()>

pub async fn release_user_control(&self, target: LogicalAddress) -> Result<()>

pub async fn close(self) -> Result<()>

Clean up the underlying Device struct. This is safer than just dropping it, as you can handle any errors that may occur.