pub struct Envelope {
pub message: MessageData,
pub initiator: LogicalAddress,
pub destination: LogicalAddress,
pub timestamp: Timestamp,
pub sequence: u32,
}Expand description
A representation of a received Message and its associated metadata.
Fields
message: MessageDataThe received message data.
initiator: LogicalAddressThe logical address of the CEC device that sent the message.
destination: LogicalAddressThe logical address to which this message was sent. Unless the Device
has the FollowerMode set to either FollowerMode::Monitor or
FollowerMode::MonitorAll, this value will either be the logical address
of the Device itself or LogicalAddress::Broadcast.
timestamp: TimestampThe time at which this message was received. This may be different from the time at which the message was read out of the kernel.
sequence: u32A system-tracked sequence number.