PinEvent

Struct PinEvent 

pub struct PinEvent {
    pub pin: Pin,
    pub state: PinState,
}
An event representing a logic level change of a physical pin.

To receive PinEvents from a Device, it must be configured with a FollowerMode of either FollowerMode::MonitorPin or FollowerMode::MonitorAll.

Fields

pin: Pin

Which physical pin generated the event.

state: PinState

The logic level of the pin.