AddressingType

Enum AddressingType 

pub enum AddressingType {
    Direct,
    Broadcast,
    Either,
}
This enum encodes the diferent ways in which a given message may be allowed to be addressed.

Hypothetically all messages can be addressed either directly or broadcast; however, the specification states that each message type only has specific ways it can be addressed. This enum encodes the various ways a message may be allowed to be addressed, per the specification, and can be queried on either a Message or an Opcode.

Variants



Direct

The given message can only be addressed directly to a specific logical address.



Broadcast

The given message can only be broadcast to all logical addresses.



Either

The given message can be either directly addressed or broadcast.