Error

Enum Error 

#[non_exhaustive]
pub enum Error { OutOfRange { expected: Range<usize>, got: usize, quantity: &'static str, }, InvalidValueForType { ty: &'static str, value: String, }, InvalidData, Timeout, Abort, NoLogicalAddress, Disconnected, Unsupported, SystemError(Errno), TxError(TxError), RxError(RxError), UnknownError(String), }
A set of common errors.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


OutOfRange

A value of a given quantity was outside of the expected range.

Fields

expected: Range<usize>
got: usize
quantity: &'static str


InvalidValueForType

Got a value for a given type that was invalid for that ty.

Fields

ty: &'static str
value: String


InvalidData

Got generic invalid data.



Timeout

A timeout occurred.



Abort

A request was aborted.



NoLogicalAddress

The request failed because the device doesn’t have a logical address.



Disconnected

The device was disconnected from the system.



Unsupported

An unsupported operation was attempted on this device.



SystemError(Errno)

A generic system error occurred.



TxError(TxError)

Got an error while transmitting a Message that did not correspond to one of the other error types.



RxError(RxError)

Got an error while receiving a Message that did not correspond to one of the other error types.



UnknownError(String)

Got an error that does not map to any of the other error types.