FollowerMode

Enum FollowerMode 

#[non_exhaustive]
pub enum FollowerMode { Disabled, Enabled, Exclusive, ExclusivePassthru, MonitorPin, Monitor, MonitorAll, }
A mode specifying how a given Device should act as a follower; that is, how receiving messages should be handled.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Disabled

Do not act as a follower.



Enabled

Act as a follower.



Exclusive

Act as a follower and disallow other processes acting as an follower while the device is open.



ExclusivePassthru

Act as a follower and pass through all messages, bypassing any in-kernel processing that would normally be done.



MonitorPin

Enable monitoring of applicable Pins. This mode requires Capabilities::MONITOR_PIN to be present on the device.



Monitor

Enable monitoring of all messages on the CEC bus, not just messages addressed to this device and broadcast messages. This requires Capabilities::MONITOR_ALL to be present on the device.



MonitorAll

Enable monitoring of applicable Pins and all messages on the CEC bus, not just messages addressed to this device and broadcast messages. This requires Capabilities::MONITOR_PIN and Capabilities::MONITOR_ALL to be present on the device.