Opcode

Enum Opcode 

#[repr(u8)]
pub enum Opcode {
Show 76 variants ActiveSource = 130, ImageViewOn = 4, TextViewOn = 13, InactiveSource = 157, RequestActiveSource = 133, RoutingChange = 128, RoutingInformation = 129, SetStreamPath = 134, Standby = 54, RecordOff = 11, RecordOn = 9, RecordStatus = 10, RecordTvScreen = 15, ClearAnalogueTimer = 51, ClearDigitalTimer = 153, ClearExtTimer = 161, SetAnalogueTimer = 52, SetDigitalTimer = 151, SetExtTimer = 162, SetTimerProgramTitle = 103, TimerClearedStatus = 67, TimerStatus = 53, CecVersion = 158, GetCecVersion = 159, GivePhysicalAddr = 131, GetMenuLanguage = 145, ReportPhysicalAddr = 132, SetMenuLanguage = 50, DeckControl = 66, DeckStatus = 27, GiveDeckStatus = 26, Play = 65, GiveTunerDeviceStatus = 8, SelectAnalogueService = 146, SelectDigitalService = 147, TunerDeviceStatus = 7, TunerStepDecrement = 6, TunerStepIncrement = 5, DeviceVendorId = 135, GiveDeviceVendorId = 140, VendorCommand = 137, VendorCommandWithId = 160, VendorRemoteButtonDown = 138, VendorRemoteButtonUp = 139, SetOsdString = 100, GiveOsdName = 70, SetOsdName = 71, MenuRequest = 141, MenuStatus = 142, UserControlPressed = 68, UserControlReleased = 69, GiveDevicePowerStatus = 143, ReportPowerStatus = 144, FeatureAbort = 0, Abort = 255, GiveAudioStatus = 113, GiveSystemAudioModeStatus = 125, ReportAudioStatus = 122, ReportShortAudioDescriptor = 163, RequestShortAudioDescriptor = 164, SetSystemAudioMode = 114, SystemAudioModeRequest = 112, SystemAudioModeStatus = 126, SetAudioRate = 154, InitiateArc = 192, ReportArcInitiated = 193, ReportArcTerminated = 194, RequestArcInitiation = 195, RequestArcTermination = 196, TerminateArc = 197, CdcMessage = 248, ReportFeatures = 166, GiveFeatures = 165, RequestCurrentLatency = 167, ReportCurrentLatency = 168, SetAudioVolumeLevel = 115,
}

Variants



ActiveSource = 130



ImageViewOn = 4



TextViewOn = 13



InactiveSource = 157



RequestActiveSource = 133



RoutingChange = 128



RoutingInformation = 129



SetStreamPath = 134



Standby = 54



RecordOff = 11



RecordOn = 9



RecordStatus = 10



RecordTvScreen = 15



ClearAnalogueTimer = 51



ClearDigitalTimer = 153



ClearExtTimer = 161



SetAnalogueTimer = 52



SetDigitalTimer = 151



SetExtTimer = 162



SetTimerProgramTitle = 103



TimerClearedStatus = 67



TimerStatus = 53



CecVersion = 158



GetCecVersion = 159



GivePhysicalAddr = 131



GetMenuLanguage = 145



ReportPhysicalAddr = 132



SetMenuLanguage = 50



DeckControl = 66



DeckStatus = 27



GiveDeckStatus = 26



Play = 65



GiveTunerDeviceStatus = 8



SelectAnalogueService = 146



SelectDigitalService = 147



TunerDeviceStatus = 7



TunerStepDecrement = 6



TunerStepIncrement = 5



DeviceVendorId = 135



GiveDeviceVendorId = 140



VendorCommand = 137



VendorCommandWithId = 160



VendorRemoteButtonDown = 138



VendorRemoteButtonUp = 139



SetOsdString = 100



GiveOsdName = 70



SetOsdName = 71



MenuRequest = 141



MenuStatus = 142



UserControlPressed = 68



UserControlReleased = 69



GiveDevicePowerStatus = 143



ReportPowerStatus = 144



FeatureAbort = 0



Abort = 255



GiveAudioStatus = 113



GiveSystemAudioModeStatus = 125



ReportAudioStatus = 122



ReportShortAudioDescriptor = 163



RequestShortAudioDescriptor = 164



SetSystemAudioMode = 114



SystemAudioModeRequest = 112



SystemAudioModeStatus = 126



SetAudioRate = 154



InitiateArc = 192



ReportArcInitiated = 193



ReportArcTerminated = 194



RequestArcInitiation = 195



RequestArcTermination = 196



TerminateArc = 197



CdcMessage = 248



ReportFeatures = 166



GiveFeatures = 165



RequestCurrentLatency = 167



ReportCurrentLatency = 168



SetAudioVolumeLevel = 115

Implementations

Source

impl Opcode

Get the AddressingType that reports whether this #opcode can be addressed directly to a specific logical address, broadcast to all logical addresses, or both.

Source

impl Opcode

pub fn can_directly_address(&self) -> bool

pub fn can_broadcast(&self) -> bool