VendorId

Struct VendorId 

pub struct VendorId(pub [u8; 3]);
A 24-bit MA-L/OUI identifying a device’s vendor or manufacturer.

These IDs are obtained from the IEEE, and a current list of OUIs can be queried from their website. A full list is also available as plain text or CSV.

Tuple Fields

0: [u8; 3]

Implementations

Source

impl VendorId

pub fn try_from_sys(vendor_id: SysVendorId) -> Result<Option<VendorId>>

Convert a linux_cec_sys::VendorId into a VendorId. Since linux_cec_sys::VendorId is just a convenience type around u32, not all values are valid, so this conversion can fail: the reserved value 0xFFFFFFFF is treated as Ok(None), and all over values outside of the valid range return Error::InvalidData.