Skip to main contentCrate linux_cec
Source pub use linux_cec_sys as sys;
- cdc
- Capability Discovery and Control support
- device
- Hardware devices interfaces
- message
- Message encoding, decoding and handling
- operand
- Message operand encoding, decoding and handling
- PhysicalAddress
- A unique 16-bit value that refers to a single
device in the topology of the CDC network.
- Timeout
- A convenience type for an unsigned 32-bit millisecond-granularity
timeout, as used in the kernel interface.
- VendorId
- A 24-bit MA-L/OUI
identifying a device’s vendor or manufacturer.
- AddressingType
- This enum encodes the diferent ways in which a given message may be
allowed to be addressed.
- Error
- A set of common errors.
- FollowerMode
- A mode specifying how a given
Device should act as
a follower; that is, how receiving messages should be handled. - InitiatorMode
- An mode specifying how a given
Device should act as
an initiator; that is, if the device should be able to send messages. - LogicalAddress
- A CEC logical address, used for identifying devices
attached to the CEC bus.
- LogicalAddressType
- The type of a CEC logical address, used for determining what type
type of device is at the given address and for requesting an address.
- Range
- RxError
- A set of error codes that correspond to
CEC_RX_STATUS. - TxError
- A set of error codes that correspond to
CEC_TX_STATUS.
- Result
- Timestamp