Hardware devices interfaces
Structs
- Async
Device - An asynchronous version of
Device. - Async
Device Poller - Capabilities
- A bitflag struct for values of the CEC_CAP_* constants
- Device
- An object for interacting with system CEC devices.
- Device
Poller - An object used for polling the status of the event and message queues in the
kernel without borrowing the
Device, created byDevice::get_poller. - Envelope
- A representation of a received
Messageand its associated metadata. - PinEvent
- An event representing a logic level change of a physical pin.
- Poll
Timeout - PollTimeout argument for polling.
Enums
- Connector
Info - Information about how the CEC device is connected to the system.
- Message
Data - An enum containing the message data, either successfully parsed or invalid.
- Pin
- A physical pin that can be monitored via
PinEvents. - PinState
- The logic level of a physical pin as reported in a
PinEvent. - Poll
Result - A return result of
Device::handle_status, containing about a single message or event was returned from the kernel. - Poll
Status - Information from a
DevicePollerabout which information is available from the kernel, to be passed toDevice::handle_status.