pub struct PinEvent {
pub pin: Pin,
pub state: PinState,
}Expand description
An event representing a logic level change of a physical pin.
To receive PinEvents from a Device, it must be configured with a
FollowerMode of either FollowerMode::MonitorPin or
FollowerMode::MonitorAll.
Fields
pin: PinWhich physical pin generated the event.
state: PinStateThe logic level of the pin.