#[non_exhaustive]pub enum InitiatorMode {
Disabled,
Enabled,
Exclusive,
}Expand description
An mode specifying how a given Device should act as
an initiator; that is, if the device should be able to send messages.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Disabled
Do not act as an initiator.
Enabled
Act as an initiator.
Exclusive
Act as an initiator and disallow other processes acting as an initiator while the device is open.